@@ -3,38 +3,36 @@ import re
 import shutil
 import logging
 from binascii import b2a_hex
-from time import time
 from datetime import datetime
 from cStringIO import StringIO
 from ConfigParser import ConfigParser
-from itertools import islice
 from shutil import rmtree
 from collections import defaultdict
 
-import tg
-from pylons import app_globals as g
-os.environ['HGRCPATH'] = '' # disable loading .hgrc
+os.environ['HGRCPATH'] = ''  # disable loading .hgrc
 from mercurial import ui, hg, cmdutil, commands
 from mercurial.error import RepoLookupError, RevlogError
-from paste.deploy.converters import asint
 
 from pymongo.errors import DuplicateKeyError
 
 from ming.base import Object
-from ming.orm import Mapper, session
+from ming.orm import Mapper
 from ming.utils import LazyProperty
 
 from allura import model as M
 from allura.lib import helpers as h
 from allura.model.repository import (
-        topological_sort,
-        GitLikeTree,
-        zipdir,
-        prefix_paths_union,
-    )
+    topological_sort,
+    GitLikeTree,
+    zipdir,
+    Commit,
+    CommitDoc,
+    TreeDoc,
+)
 
 log = logging.getLogger(__name__)
 
+
 class Repository(M.Repository):
     tool_name='Hg'
     repo_id='hg'
@@ -57,12 +55,14 @@ class Repository(M.Repository):
     def rev_to_commit_id(self, rev):
         return self._impl.rev_parse(rev)
 
+
 class HgUI(ui.ui):
     '''Hg UI subclass that suppresses reporting of untrusted hgrc files.'''
     def __init__(self, *args, **kwargs):
         super(HgUI, self).__init__(*args, **kwargs)
         self._reportuntrusted = False
 
+
 class HgImplementation(M.RepositoryImplementation):
     re_hg_user = re.compile('(.*) <(.*)>')
 
@@ -112,14 +112,15 @@ class HgImplementation(M.RepositoryImplementation):
 
     def commit(self, rev):
         '''Return a Commit object.  rev can be _id or a branch/tag name'''
-        result = M.repo.Commit.query.get(_id=rev)
+        result = Commit.query.get(_id=rev)
         if result is None:
             try:
                 impl = self._hg[str(rev)]
-                result = M.repo.Commit.query.get(_id=impl.hex())
+                result = Commit.query.get(_id=impl.hex())
             except Exception, e:
                 log.exception(e)
-        if result is None: return None
+        if result is None:
+            return None
         result.set_context(self._repo)
         return result
 
@@ -153,7 +154,7 @@ class HgImplementation(M.RepositoryImplementation):
             if obj.hex() in graph: continue
             if not all_commits:
                 # Look up the object
-                if M.repo.Commit.query.find(dict(_id=obj.hex())).count():
+                if Commit.query.find(dict(_id=obj.hex())).count():
                     graph[obj.hex()] = set() # mark as parentless
                     continue
             parents = self.real_parents(obj)
@@ -164,7 +165,6 @@ class HgImplementation(M.RepositoryImplementation):
         return list(topological_sort(graph))
 
     def refresh_commit_info(self, oid, seen, lazy=True):
-        from allura.model.repo import CommitDoc
         ci_doc = CommitDoc.m.get(_id=oid)
         if ci_doc and lazy: return False
         obj = self._hg[oid]
@@ -200,7 +200,6 @@ class HgImplementation(M.RepositoryImplementation):
         return True
 
     def refresh_tree_info(self, tree, seen, lazy=True):
-        from allura.model.repo import TreeDoc
         if lazy and tree.hex() in seen: return
         seen.add(tree.hex())
         doc = TreeDoc(dict(
